@@ -9,26 +9,34 @@ def copy(func: Callable) -> Callable:
         help='Copy the directory text to clipboard'
     )(func)
 
-def create_readme(func: Callable) -> Callable:
+def readme(func: Callable) -> Callable:
     return click.option(
-        '--create_readme',
+        '--readme',
         default=False,
         is_flag=True,
         help='Generate README.md file'
     )(func)
 
-def create_readme_plus(func: Callable) -> Callable:
+def narrative(func: Callable) -> Callable:
     return click.option(
-        '--create_readme_plus',
-        default=False,
-        is_flag=True,
-        help='Generate readme for larger repositories'
+        '--narrative',
+        default="",
+        type=str,
+        help='Provide a narrative to guide the tone and content of the README'
     )(func)
 
-def create_tests(func: Callable) -> Callable:
+def gpt3(func: Callable) -> Callable:
     return click.option(
-        '--create_tests',
+        '--gpt3',
         default=False,
         is_flag=True,
-        help='Generate unit tests for each code file'
+        help='Use the GPT-3.5 Turbo model'
+    )(func)
+
+def docs(func: Callable) -> Callable:
+    return click.option(
+        '--docs',
+        default=False,
+        is_flag=True,
+        help='Generate documentation for all code files'
     )(func)
